@@ -1,7 +1,5 @@
 """Test reading, writing and extracting archives."""
 
-from __future__ import division, print_function, unicode_literals
-
 import io
 import json
 
@@ -9,7 +7,7 @@ import libarchive
 from libarchive.entry import format_time
 from libarchive.extract import EXTRACT_OWNER, EXTRACT_PERM, EXTRACT_TIME
 from libarchive.write import memory_writer
-from mock import patch
+from unittest.mock import patch
 import pytest
 
 from . import check_archive, in_dir, treestat
@@ -28,6 +26,8 @@ def test_buffers(tmpdir):
     # Read the archive and check that the data is correct
     with libarchive.memory_reader(buf) as archive:
         check_archive(archive, tree)
+        assert archive.format_name == b'GNU tar format'
+        assert archive.filter_names == [b'xz']
 
     # Extract the archive in tmpdir and check that the data is intact
     with in_dir(tmpdir.strpath):
@@ -52,6 +52,8 @@ def test_fd(tmpdir):
     archive_file.seek(0)
     with libarchive.fd_reader(fd) as archive:
         check_archive(archive, tree)
+        assert archive.format_name == b'GNU tar format'
+        assert archive.filter_names == [b'bzip2']
 
     # Extract the archive in tmpdir and check that the data is intact
     archive_file.seek(0)
@@ -75,6 +77,8 @@ def test_files(tmpdir):
     # Read the archive and check that the data is correct
     with libarchive.file_reader(archive_path) as archive:
         check_archive(archive, tree)
+        assert archive.format_name == b'POSIX ustar format'
+        assert archive.filter_names == [b'gzip']
 
     # Extract the archive in tmpdir and check that the data is intact
     with in_dir(tmpdir.strpath):
@@ -97,6 +101,8 @@ def test_custom_writer_and_stream_reader():
     # Read the archive and check that the data is correct
     with libarchive.stream_reader(stream, 'zip') as archive:
         check_archive(archive, tree)
+        assert archive.format_name == b'ZIP 2.0 (deflation)'
+        assert archive.filter_names == []
 
 
 @patch('libarchive.ffi.write_fail')
@@ -119,6 +125,14 @@ def test_write_not_fail(write_fail_mock):
     assert not write_fail_mock.called
 
 
+def test_adding_nonexistent_file_to_archive():
+    stream = io.BytesIO()
+    with libarchive.custom_writer(stream.write, 'zip') as archive:
+        with pytest.raises(libarchive.ArchiveError):
+            archive.add_files('nonexistent')
+        archive.add_files('libarchive/')
+
+
 @pytest.mark.parametrize(
     'archfmt,data_bytes',
     [('zip', b'content'),
@@ -147,7 +161,8 @@ def test_adding_entry_from_memory(archfmt, data_bytes):
     with libarchive.custom_writer(write_callback, archfmt) as archive:
         archive.add_file_from_memory(
             entry_path, entry_size, entry_data,
-            atime=atime, mtime=mtime, ctime=ctime, birthtime=btime
+            atime=atime, mtime=mtime, ctime=ctime, birthtime=btime,
+            uid=1000, gid=1000,
         )
 
     buf = b''.join(blocks)
@@ -164,3 +179,5 @@ def test_adding_entry_from_memory(archfmt, data_bytes):
                 assert archive_entry.birthtime in (
                     btime[0], format_time(*btime)
                 )
+            assert archive_entry.uid == 1000
+            assert archive_entry.gid == 1000
