@@ -35,7 +35,7 @@ def get_version():
 
     else:
         # Extract the version from the PKG-INFO file.
-        with open(join(d, 'PKG-INFO')) as f:
+        with open(join(d, 'PKG-INFO'), encoding='utf-8', errors='replace') as f:
             version = version_re.search(f.read()).group(1)
 
     return version
